import {Component, Input, OnInit} from '@angular/core';
import {Item} from "../../../project/game-model/inventory/Item";
import {MatTableDataSource} from "@angular/material/table";
import {ItemProperty} from "../../../project/game-model/inventory/ItemProperty";
import {animate, state, style, transition, trigger} from "@angular/animations";

@Component({
  selector: 'app-item-property-editor',
  templateUrl: './item-property-editor.component.html',
  styleUrl: './item-property-editor.component.scss',
  animations: [
    trigger('detailExpand', [
      state('collapsed,void', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})
export class ItemPropertyEditorComponent implements OnInit{

  @Input() item: Item | undefined
  editedItemProperty: ItemProperty | undefined
  expandedElement: ItemProperty | undefined

  displayedColumns: string[] = ['name', 'property', 'delete']
  columnsToDisplayWithExpand = [...this.displayedColumns, 'expand'];

  datasource: MatTableDataSource<ItemProperty> = new MatTableDataSource<ItemProperty>();

  ngOnInit() {
    this.datasource.data = this.item!.itemProperties
  }

  deleteItemProperty(itemProperty: ItemProperty) {
    this.item!.itemProperties = this.item!.itemProperties.filter(property => property.propertyName !== itemProperty.propertyName)
    this.datasource.data = this.item!.itemProperties
  }
}
