import {Component, Input, OnInit} from '@angular/core';

import {MatFormField} from "@angular/material/form-field";
import {MatInput} from "@angular/material/input";
import {FormControl, FormGroupDirective, FormsModule, NgForm, Validators} from "@angular/forms";
import {NgIf} from "@angular/common";
import {ErrorStateMatcher} from "@angular/material/core";
import {ElectronService} from "../../core/services";
import {ScriptAccount} from "../../project/game-model/scriptAccounts/ScriptAccount";

export class MyErrorStateMatcher implements ErrorStateMatcher {
  isErrorState(control: FormControl | null, form: FormGroupDirective | NgForm | null): boolean {
    const isSubmitted = form && form.submitted;
    return !!(control && control.invalid && (control.dirty || control.touched || isSubmitted));
  }
}
@Component({
  selector: 'app-script-account-editor',
  templateUrl: './script-account-editor.component.html',
  styleUrl: './script-account-editor.component.scss'
})
export class ScriptAccountEditorComponent implements OnInit{
  @Input("scriptAccount") scriptAccount : ScriptAccount | undefined

  minCtrl: FormControl = new FormControl(0, [Validators.required, Validators.pattern('^[-]?[0-9]*$')]);
  maxCtrl: FormControl = new FormControl(100, [Validators.required, Validators.pattern('^[-]?[0-9]*$')]);
  matcher = new MyErrorStateMatcher();

  constructor(private electronService: ElectronService) {
  }
  ngOnInit() {
    this.minCtrl.setValue(this.scriptAccount!.minValue);
    this.maxCtrl.setValue(this.scriptAccount!.maxValue);
  }


  onUpdateMinValue(event: Event) {
    this.scriptAccount!.minValue = Number(this.minCtrl.value);
    this.scriptAccount!.onModifyContent();
  }

  onUpdateMaxValue() {
    this.scriptAccount!.maxValue = Number(this.maxCtrl.value);
    this.scriptAccount!.onModifyContent();
  }

  save() {
    const jsonString = JSON.stringify(this.scriptAccount!, null, 4);
    this.electronService.ipcRenderer.send('save-json', jsonString, this.scriptAccount!.componentName + ".json");
  }
}
